@@ -5,8 +5,8 @@
 do
  assert(luaotfload_module, "This is a part of luaotfload and should not be loaded independently") { 
      name          = "luaotfload-harf-var-ttf",
-     version       = "3.23",       --TAGVERSION
-     date          = "2022-10-03", --TAGDATE
+     version       = "3.28",       --TAGVERSION
+     date          = "2024-02-14", --TAGDATE
      description   = "luaotfload submodule / gvar table processing",
      license       = "GPL v2.0",
      author        = "Marcel Krüger",
@@ -350,7 +350,7 @@ local function read_points(gvar_data, offset)
     return true, offset
   end
   if point_count & 0x80 ~= 0 then
-    point_count = ((point_count & 0x7F) << 8) | sio.readcardinal1(gvar_data, suboffset)
+    point_count = ((point_count & 0x7F) << 8) | sio.readcardinal1(gvar_data, offset)
     offset = offset + 1
   end
   local points = lua.newtable(point_count, 0)
